@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/extensions/nsplugin/src/qnp.cpp   2.3.0   edited 2001-02-09 $
+** $Id: qt/extensions/nsplugin/src/qnp.cpp   2.3.2   edited 2001-07-22 $
 **
 ** Implementation of Qt extension classes for Netscape Plugin support.
 **
@@ -344,13 +344,6 @@ public:
 	{
 	    checkFocussedWidget();
 	}
-
-#ifdef _WS_WIN_
-        // Without this then widgets will not show in Windows at all
-        if ( event->type() == QEvent::Show || event->type() == QEvent::Paint )
-            QApplication::sendPostedEvents();
-#endif
-
 	return QApplication::notify( obj, event );
     }
 #endif
@@ -739,7 +732,7 @@ NPP_SetWindow(NPP instance, NPWindow* window)
 	    next_pi = This;
 	    /* This->widget = */ // (happens sooner - in QNPWidget constructor)
 		This->instance->newWindow();
-	    This->widget->show();
+	    This->widget->show(); 
 	} else {
 	    // New window for existing widget, and all its children.
 	    This->widget->setWindow(FALSE);
@@ -1212,7 +1205,7 @@ QNPWidget::QNPWidget() :
 #ifdef _WS_WIN_
     // Communicator and explorer give us an unshown
     // widget.  Navigator gives us a shown one.
-    show();
+    QWidget::show();
 #endif
 }
 
@@ -1284,7 +1277,8 @@ void createNewWindowsForAllChildren(QWidget* parent, int indent=0)
 	    // Fix children first, so propagation can work
 	    createNewWindowsForAllChildren(c,indent+1);
 	    c->fix();
-	    if ( vis ) c->show(); // Now that all children are valid.
+	    if ( vis ) 
+		c->show(); // Now that all children are valid.			    
 	    ++it;
 	}
 	delete list;
