@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/dialogs/qfontdialog.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/src/dialogs/qfontdialog.cpp   2.3.2   edited 2001-09-11 $
 **
 ** Implementation of QFontDialog
 **
@@ -539,7 +539,7 @@ void QFontDialog::updateScripts()
 	qWarning( "QFontDialog::updateFamilies: Internal error, "
 		  "no character sets for family \"%s\"",
 		  (const char *) d->family );
-	return;
+	d->charSetNames.append( "Any" );
     }
 
     QStringList::Iterator it = d->charSetNames.begin();
@@ -626,10 +626,18 @@ void QFontDialog::scriptHighlighted( int index )
 void QFontDialog::scriptHighlighted( const QString &s )
 {
     d->charSet = s;
-
+    QString currentStyle = d->styleList->currentText();
     updateStyles();
-    if ( d->styleList->count() != 0 )
-	d->styleList->setCurrentItem( 0 );  // Will call styleHighlighted
+    if ( d->styleList->count() != 0 ) {
+	for ( int i = 0 ; i < (int)d->styleList->count() ; i++ ) {
+	    if ( currentStyle == d->styleList->text(i) ) {
+		d->styleList->setCurrentItem( i ); // Will call styleHighlighted
+		break;
+	    }
+	}
+        if ( d->styleList->currentItem() == -1 )
+	    d->styleList->setCurrentItem( 0 ); // Will call styleHighlighted
+    }
 }
 
 /*!
