@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/kernel/qpalette.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/src/kernel/qpalette.cpp   2.3.2   edited 2001-05-30 $
 **
 ** Implementation of QColorGroup and QPalette classes
 **
@@ -164,7 +164,7 @@
 
 QColorGroup::QColorGroup()
 {
-    br = new QBrush[NColorRoles];	// all colors become black
+    br = new QBrush[(uint)NColorRoles];	// all colors become black
 
     // The d pointer may allow sharing in the future.  The br pointer
     // then will be a redundant pointer that makes possible the inlines
@@ -179,7 +179,7 @@ QColorGroup::QColorGroup()
 */
 QColorGroup::QColorGroup( const QColorGroup& other )
 {
-    br = new QBrush[NColorRoles];
+    br = new QBrush[(uint)NColorRoles];
     for (int i=0; i<NColorRoles; i++)
 	br[i] = other.br[i];
     d = 0;
@@ -216,7 +216,7 @@ Such long lists of arguments are rather error-prone.
 			   const QBrush &bright_text, const QBrush &base,
 			   const QBrush &background)
 {
-    br = new QBrush[NColorRoles];
+    br = new QBrush[(uint)NColorRoles];
     br[Foreground]      = foreground;
     br[Button] 	 	= button;
     br[Light] 		= light;
@@ -245,7 +245,7 @@ QColorGroup::QColorGroup( const QColor &foreground, const QColor &background,
 			  const QColor &mid,
 			  const QColor &text, const QColor &base )
 {
-    br = new QBrush[NColorRoles];
+    br = new QBrush[(uint)NColorRoles];
     br[Foreground]      = QBrush(foreground);
     br[Button]          = QBrush(background);
     br[Light]           = QBrush(light);
@@ -478,6 +478,13 @@ bool QColorGroup::operator==( const QColorGroup &g ) const
 */ // ### should mention the constructors, copy stuff and isCopyOf()
 
 
+QPalette::QPalData *QPalette::defPalData = 0;
+void QPalette::cleanupDefPal()
+{
+    delete defPalData;
+    defPalData = 0;
+}
+
 static int palette_count = 1;
 
 /*!
@@ -486,9 +493,14 @@ static int palette_count = 1;
 
 QPalette::QPalette()
 {
-    data = new QPalData;
-    CHECK_PTR( data );
-    data->ser_no = palette_count++;
+    if ( !defPalData ) {                // create common palette data
+	defPalData = new QPalData;      //   for the default palette
+	CHECK_PTR( defPalData );
+	defPalData->ser_no = palette_count++;
+	qAddPostRoutine( cleanupDefPal );
+    }
+    data = defPalData;
+    data->ref();
 }
 
 /*!\obsolete
