@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/kernel/qpolygonscanner.cpp   2.3.0   edited 2001-02-26 $
+** $Id: qt/src/kernel/qpolygonscanner.cpp   2.3.2   edited 2001-03-06 $
 **
 ** Implementation of QPolygonScanner class
 **
@@ -723,6 +723,18 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
     scan( pa, winding, index, npoints, TRUE );
 }
 
+/*! \overload
+
+  If \a stitchable is FALSE, the right and bottom edges of the polygon are
+    included. This causes adjacent polygons to overlap.
+
+ */
+void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int npoints, bool stitchable)
+{
+    scan( pa, winding, index, npoints,
+	stitchable ? Edge(Left+Top) : Edge(Left+Right+Top+Bottom) );
+}
+
 /*!
   Calls processSpans() for all scanlines of the polygon defined by \a npoints
   starting at \a index in \a pa.
@@ -730,10 +742,13 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
   If \a winding is TRUE, the Winding algorithm rather than the Odd-Even
     rule is used.
 
-  If \a stitchable is FALSE, the right and bottom edges of the polygon are
-    included. This causes adjacent polygons to overlap.
+  The \a edges is any bitwise combination of
+    QPolygonScanner::Left, 
+    QPolygonScanner::Right, 
+    QPolygonScanner::Top, and
+    QPolygonScanner::Bottom, and determines which edges are included.
 */
-void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int npoints, bool stitchable)
+void QPolygonScanner::scan( const QPointArray& pa, bool winding, int index, int npoints, Edge edges )
 {
     DDXPointPtr ptsIn = (DDXPointPtr)pa.data();
     ptsIn += index;
@@ -752,7 +767,10 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
     EdgeTableEntry *pETEs;          /* Edge Table Entries buff */
     ScanLineListBlock SLLBlock;     /* header for ScanLineList */
     int fixWAET = 0;
-    int stitch = stitchable ? 0 : 1;
+    int edge_l = (edges & Left) ? 1 : 0;
+    int edge_r = (edges & Right) ? 1 : 0;
+    int edge_t = (edges & Top) ? 1 : 0;
+    int edge_b = (edges & Bottom) ? 1 : 0;
 
     if (npoints == -1)
 	npoints = pa.size();
@@ -777,7 +795,7 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
         /*
          *  for each scanline
          */
-        for (y = ET.ymin; y < ET.ymax+stitch; y++)
+        for (y = ET.ymin+1-edge_t; y < ET.ymax+edge_b; y++)
         {
             /*
              *  Add a new edge to the active edge table when we
@@ -796,9 +814,10 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
              */
             while (pAET)
             {
-                ptsOut->x = pAET->bres.minor;
+                ptsOut->x = pAET->bres.minor + 1 - edge_l;
 		ptsOut++->y = y;
-                *width++ = pAET->next->bres.minor - pAET->bres.minor + stitch;
+                *width++ = pAET->next->bres.minor - pAET->bres.minor
+		    - 1 + edge_l + edge_r;
                 nPts++;
 
                 /*
@@ -822,7 +841,7 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
         /*
          *  for each scanline
          */
-        for (y = ET.ymin; y < ET.ymax+stitch; y++)
+        for (y = ET.ymin+1-edge_t; y < ET.ymax+edge_b; y++)
         {
             /*
              *  Add a new edge to the active edge table when we
@@ -850,9 +869,9 @@ void QPolygonScanner::scan(const QPointArray& pa, bool winding, int index, int n
                  */
                 if (pWETE == pAET)
                 {
-                    ptsOut->x = pAET->bres.minor;
+                    ptsOut->x = pAET->bres.minor + 1 - edge_l;
 		    ptsOut++->y = y;
-                    *width++ = pAET->nextWETE->bres.minor - pAET->bres.minor + stitch;
+                    *width++ = pAET->nextWETE->bres.minor - pAET->bres.minor - 1 + edge_l + edge_r;
                     nPts++;
 
                     /*
