@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/kernel/qwmatrix.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/src/kernel/qwmatrix.cpp   2.3.2   edited 2001-06-22 $
 **
 ** Implementation of QWMatrix class
 **
@@ -43,7 +43,7 @@ double qsincos( double, bool calcCos );		// defined in qpainter_x11.cpp
 #include <math.h>
 #endif
 
-#ifndef QT_NO_TRANSFORMATIONS
+#ifndef QT_NO_WMATRIX
 
 // NOT REVISED
 /*!
@@ -402,8 +402,8 @@ QWMatrix &QWMatrix::rotate( double a )
 QWMatrix QWMatrix::invert( bool *invertible ) const
 {
     double det = _m11*_m22 - _m12*_m21;
-    if ( QABS(det) < 0.000001 ) {		// very close to zero
-	if ( invertible )			//   (whatever that means...)
+    if ( det == 0.0 ) {
+	if ( invertible )
 	    *invertible = FALSE;		// singular matrix
 	QWMatrix defaultMatrix;
 	return defaultMatrix;
@@ -533,5 +533,5 @@ QDataStream &operator>>( QDataStream &s, QWMatrix &m )
     return s;
 }
 #endif // QT_NO_DATASTREAM
-#endif // QT_NO_TRANSFORMATIONS
+#endif // QT_NO_WMATRIX
 
