@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qrangecontrol.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/src/widgets/qrangecontrol.cpp   2.3.2   edited 2001-09-21 $
 **
 ** Implementation of QRangeControl class
 **
@@ -114,8 +114,9 @@ QRangeControl::QRangeControl()
     maxVal  = 99;
     line    = 1;
     page    = 10;
-    val	    = prevVal = 0;
-    d       = 0;
+    val	    = 0;
+    prevVal = -1;
+    d	    = 0;
 }
 
 /*!
@@ -131,12 +132,13 @@ QRangeControl::QRangeControl( int minValue, int maxValue,
 			      int lineStep, int pageStep,
 			      int value )
 {
-    minVal = minValue;
-    maxVal = maxValue;
-    line   = QABS( lineStep );
-    page   = QABS( pageStep );
-    val	   = prevVal = bound( value );
-    d       = 0;
+    minVal  = minValue;
+    maxVal  = maxValue;
+    line    = QABS( lineStep );
+    page    = QABS( pageStep );
+    prevVal = minVal - 1;
+    val	    = bound( value );
+    d	    = 0;
 }
 
 
@@ -179,8 +181,9 @@ QRangeControl::QRangeControl( int minValue, int maxValue,
 
 void QRangeControl::setValue( int value )
 {
+    int lprevVal = prevVal;
     directSetValue( value );
-    if ( prevVal != val )
+    if ( lprevVal != val || prevVal != val )
 	valueChange();
 }
 
@@ -215,7 +218,7 @@ void QRangeControl::directSetValue(int value)
 
 void QRangeControl::addPage()
 {
-    if ( value() + pageStep() > value() )
+    if ( value() + pageStep() < maxValue() )
 	setValue( value() + pageStep() );
     else
 	setValue( maxValue() );
@@ -232,7 +235,7 @@ void QRangeControl::addPage()
 
 void QRangeControl::subtractPage()
 {
-    if ( value() - pageStep() < value() )
+    if ( value() - pageStep() > minValue() )
 	setValue( value() - pageStep() );
     else
 	setValue( minValue() );
@@ -249,7 +252,7 @@ void QRangeControl::subtractPage()
 
 void QRangeControl::addLine()
 {
-    if ( value() + lineStep() > value() )
+    if ( value() + lineStep() < maxValue() )
 	setValue( value() + lineStep() );
     else
 	setValue( maxValue() );
@@ -266,7 +269,7 @@ void QRangeControl::addLine()
 
 void QRangeControl::subtractLine()
 {
-    if ( value() - lineStep() < value() )
+    if ( value() - lineStep() > minValue() )
 	setValue( value() - lineStep() );
     else
 	setValue( minValue() );
@@ -321,7 +324,8 @@ void QRangeControl::setRange( int minValue, int maxValue )
     int tmp = bound( val );
     rangeChange();
     if ( tmp != val ) {
-	prevVal = tmp;
+	prevVal = val;
+	val = tmp;
 	valueChange();
     }
 }
