@@ -564,12 +564,20 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 	    dia = new QDesignerDialog( (FormWindow*)parent, parent, name );
 	else
 	    dia = new QDialog( parent, name );
+#if defined(QT_NON_COMMERCIAL)
+	if ( parent && !parent->inherits("MainWindow") )
+#else
 	if ( parent )
+#endif
 	    dia->reparent( parent, QPoint( 0, 0 ), TRUE );
 	return dia;
     } else if ( className == "QWizard" ) {
 	QWizard *wiz = new QDesignerWizard( parent, name );
+#if defined(QT_NON_COMMERCIAL)
+	if ( parent && !parent->inherits("MainWindow") )
+#else
 	if ( parent )
+#endif
 	    wiz->reparent( parent, QPoint( 0, 0 ), TRUE );
 	if ( init && parent && parent->inherits( "FormWindow" ) ) {
 	    QDesignerWidget *dw = new QDesignerWidget( (FormWindow*)parent, wiz, "page" );
@@ -822,6 +830,11 @@ void WidgetFactory::initChangedProperties( QObject *o )
     } else if ( o->inherits( "QTabWidget" ) || o->inherits( "QWizard" ) ) {
 	MetaDataBase::setPropertyChanged( o, "pageTitle", TRUE );
 	MetaDataBase::setPropertyChanged( o, "pageName", TRUE );
+#ifndef QT_NO_TABLE
+    } else if ( o->inherits( "QTable" ) ) {
+	MetaDataBase::setPropertyChanged( o, "numRows", TRUE );
+	MetaDataBase::setPropertyChanged( o, "numCols", TRUE );
+#endif
     }
 }
 
